@@ -87,7 +87,7 @@ def _encode(s):
     return s.encode() if PY2 and isinstance(s, text_type) else s
 
 
-class FTPFile(object):
+class FTPFile(io.IOBase):
 
     def __init__(self, ftpfs, path, mode):
         self.fs = ftpfs
@@ -98,7 +98,6 @@ class FTPFile(object):
         self.ftp = self._open_ftp()
         self._read_conn = None
         self._write_conn = None
-        self._closed = False
 
     def _open_ftp(self):
         ftp = self.fs._open_ftp()
@@ -132,29 +131,9 @@ class FTPFile(object):
         _repr = "<ftpfile {!r} {!r} {!r}>"
         return _repr.format(self.fs.ftp_url, self.path, self.mode)
 
-    def __enter__(self):
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        self.close()
-
-    def __iter__(self):
-        return line_iterator(self)
-
-    def __del__(self):
-        self.close()
-
-    def flush(self):
-        pass
-
-    def next(self):
-        return self.readline()
-
-    __next__ = next
-
     def close(self):
-        with self._lock:
-            if not self._closed:
+        if not self.closed:
+            with self._lock:
                 try:
                     if self._write_conn is not None:
                         self._write_conn.close()
@@ -167,11 +146,14 @@ class FTPFile(object):
                     except error_temp:  # pragma: nocover
                         pass
                 finally:
-                    self._closed = True
+                    super(FTPFile, self).close()
 
     def tell(self):
         return self.pos
 
+    def readable(self):
+        return self.mode.reading
+
     def read(self, size=None):
         if not self.mode.reading:
             raise IOError('File not open for reading')
@@ -211,6 +193,9 @@ class FTPFile(object):
                 break
         return lines
 
+    def writable(self):
+        return self.mode.writing
+
     def write(self, data):
         if not self.mode.writing:
             raise IOError('File not open for writing')
@@ -242,6 +227,8 @@ class FTPFile(object):
                 if len(data) < size:
                     f.write(b'\0' * (size - len(data)))
 
+    def seekable(self):
+        return True
 
     def seek(self, pos, whence=Seek.set):
         if whence not in (Seek.set, Seek.current, Seek.end):
@@ -322,7 +309,7 @@ class FTPFS(FS):
 
     def _open_ftp(self):
         _ftp = FTP()
-        #_ftp.set_debuglevel(2)
+        _ftp.set_debuglevel(0)
         with ftp_errors(self):
             _ftp.connect(self.host, self.port, self.timeout)
             _ftp.login(self.user, self.passwd, self.acct)
